@@ -9,7 +9,7 @@ from djangoldp.models import Model
 
 class Profile(Model):
     user = models.OneToOneField(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name="profile")
-    slug = models.SlugField(unique=True)
+    slug = models.SlugField(unique=True, blank=True)
     available = models.NullBooleanField(blank=True)
     job = models.CharField(max_length=150, blank=True)
     city = models.CharField(max_length=255, blank=True)
